You are viewing a plain text version of this content. The canonical link for it is here.
Posted to jetspeed-dev@portals.apache.org by ta...@apache.org on 2006/12/04 19:11:14 UTC

svn commit: r482272 - in /portals/jetspeed-2/trunk/jetspeed-api/src/java/org/apache/jetspeed/capabilities: Capabilities.java CapabilitiesException.java

Author: taylor
Date: Mon Dec  4 10:11:13 2006
New Revision: 482272

URL: http://svn.apache.org/viewvc?view=rev&rev=482272
Log:
more specific exceptions

Added:
    portals/jetspeed-2/trunk/jetspeed-api/src/java/org/apache/jetspeed/capabilities/CapabilitiesException.java
Modified:
    portals/jetspeed-2/trunk/jetspeed-api/src/java/org/apache/jetspeed/capabilities/Capabilities.java

Modified: portals/jetspeed-2/trunk/jetspeed-api/src/java/org/apache/jetspeed/capabilities/Capabilities.java
URL: http://svn.apache.org/viewvc/portals/jetspeed-2/trunk/jetspeed-api/src/java/org/apache/jetspeed/capabilities/Capabilities.java?view=diff&rev=482272&r1=482271&r2=482272
==============================================================================
--- portals/jetspeed-2/trunk/jetspeed-api/src/java/org/apache/jetspeed/capabilities/CapabilitiesException.java (added)
+++ portals/jetspeed-2/trunk/jetspeed-api/src/java/org/apache/jetspeed/capabilities/CapabilitiesException.java Mon Dec  4 10:11:13 2006
@@ -0,0 +1,48 @@
+/*
+ * Copyright 2000-2004 The Apache Software Foundation.
+ * 
+ * Licensed under the Apache License, Version 2.0 (the "License");
+ * you may not use this file except in compliance with the License.
+ * You may obtain a copy of the License at
+ * 
+ *      http://www.apache.org/licenses/LICENSE-2.0
+ * 
+ * Unless required by applicable law or agreed to in writing, software
+ * distributed under the License is distributed on an "AS IS" BASIS,
+ * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+ * See the License for the specific language governing permissions and
+ * limitations under the License.
+ */
+package org.apache.jetspeed.capabilities;
+
+import org.apache.jetspeed.exception.JetspeedException;
+
+/**
+ * CapabilitiesException
+ *
+ * @author <a href="mailto:taylor@apache.org">David Sean Taylor</a>
+ * @version $Id: $
+ */
+public class CapabilitiesException extends JetspeedException
+{
+    public CapabilitiesException() 
+    {
+        super();
+    }
+
+    public CapabilitiesException( String message ) 
+    {
+        super( message );
+    }
+
+    public CapabilitiesException(Throwable nested)
+    {
+        super(nested);
+    }
+    
+    public CapabilitiesException(String msg, Throwable nested)
+    {
+        super(msg, nested);
+    }
+    
+}



---------------------------------------------------------------------
To unsubscribe, e-mail: jetspeed-dev-unsubscribe@portals.apache.org
For additional commands, e-mail: jetspeed-dev-help@portals.apache.org
--- portals/jetspeed-2/trunk/jetspeed-api/src/java/org/apache/jetspeed/capabilities/Capabilities.java (original)
+++ portals/jetspeed-2/trunk/jetspeed-api/src/java/org/apache/jetspeed/capabilities/Capabilities.java Mon Dec  4 10:11:13 2006
@@ -207,8 +207,8 @@
      * 
      * @param mediaType valid mediatype object
      */
-    public void storeMediaType(MediaType mediaType) throws Exception;
-    	//TODO: change exception to better indicate cause
+    public void storeMediaType(MediaType mediaType) throws CapabilitiesException;
+    	//TODO: change CapabilitiesException to better indicate cause
  
 	/**
      * delete existing media type from backend storage
@@ -216,7 +216,7 @@
      * @param mediaType valid mediatype object
      */
     public void deleteMediaType(MediaType mediaType)
-            throws Exception;
+            throws CapabilitiesException;
 
 	
 	/**
@@ -224,7 +224,7 @@
      * 
      * @param capability valid capability object
      */
-    public void storeCapability(Capability capability) throws Exception;
+    public void storeCapability(Capability capability) throws CapabilitiesException;
 
     /**
      * delete existing capability from backend storage
@@ -232,15 +232,14 @@
      * @param capability valid capability object
      */
     public void deleteCapability(Capability capability)
-            throws Exception;
+            throws CapabilitiesException;
 
 	/**
      * Save mime type to backend storage
      * 
      * @param mimeType valid mimetype object
      */
-    public void storeMimeType(MimeType mimeType) throws Exception;
-    	//TODO: change exception to better indicate cause
+    public void storeMimeType(MimeType mimeType) throws CapabilitiesException;
  
 	/**
      * delete existing mime type from backend storage
@@ -248,7 +247,7 @@
      * @param mimeType valid mimetype object
      */
     public void deleteMimeType(MimeType mimeType)
-            throws Exception;
+            throws CapabilitiesException;
 
 
 	
@@ -257,7 +256,7 @@
      * 
      * @param client valid Client object
      */
-    public void storeClient(Client client) throws Exception;
+    public void storeClient(Client client) throws CapabilitiesException;
 
     /**
      * delete existing client from backend storage
@@ -265,6 +264,6 @@
      * @param client valid client object
      */
     public void deleteClient(Client client)
-            throws Exception;
+            throws CapabilitiesException;
 
 }

Added: portals/jetspeed-2/trunk/jetspeed-api/src/java/org/apache/jetspeed/capabilities/CapabilitiesException.java
URL: http://svn.apache.org/viewvc/portals/jetspeed-2/trunk/jetspeed-api/src/java/org/apache/jetspeed/capabilities/CapabilitiesException.java?view=auto&rev=482272
==============================================================================